@@ -71,24 +71,6 @@ ProcInfo* ProcInfo::find(pid_t pid)
 }
 
 
-
-static void
-set_proctree_reorderable(ProcData *procdata)
-{
-    GList *columns, *col;
-    GtkTreeView *proctree;
-
-    proctree = GTK_TREE_VIEW(procdata->tree);
-
-    columns = gtk_tree_view_get_columns (proctree);
-
-    for(col = columns; col; col = col->next)
-        gtk_tree_view_column_set_reorderable(static_cast<GtkTreeViewColumn*>(col->data), TRUE);
-
-    g_list_free(columns);
-}
-
-
 static void
 cb_columns_changed(GtkTreeView *treeview, gpointer user_data)
 {
@@ -157,7 +139,6 @@ proctable_set_columns_order(GtkTreeView *treeview, GSList *order)
 }
 
 
-
 GSList*
 proctable_get_columns_order(GtkTreeView *treeview)
 {
@@ -208,7 +189,7 @@ save_column_width (gpointer data)
     return FALSE;
 }
 
-void
+static void
 cb_proctable_column_resized(GtkWidget *widget, GParamSpec *pspec, gpointer data)
 {
     current_column = GTK_TREE_VIEW_COLUMN(widget);
@@ -332,7 +313,6 @@ proctable_new (ProcData * const procdata)
                                          search_equal_func,
                                          NULL,
                                          NULL);
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (proctree), TRUE);
     g_object_unref (G_OBJECT (model));
 
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (proctree));
@@ -355,7 +335,8 @@ proctable_new (ProcData * const procdata)
     gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
     gtk_tree_view_column_set_resizable (column, TRUE);
     gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
-    gtk_tree_view_column_set_min_width (column, 1);
+    gtk_tree_view_column_set_min_width (column, 20);
+    gtk_tree_view_column_set_reorderable (column, TRUE);
     g_signal_connect(G_OBJECT(column), "notify::fixed-width", G_CALLBACK(cb_proctable_column_resized), procdata->settings);
     gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (proctree), column);
@@ -370,8 +351,9 @@ proctable_new (ProcData * const procdata)
         col = gtk_tree_view_column_new();
         gtk_tree_view_column_pack_start(col, cell, TRUE);
         gtk_tree_view_column_set_title(col, _(titles[i]));
-        gtk_tree_view_column_set_resizable(col, TRUE);
         gtk_tree_view_column_set_sort_column_id(col, i);
+        gtk_tree_view_column_set_resizable(col, TRUE);
+        gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
         g_signal_connect(G_OBJECT(col), "notify::fixed-width", G_CALLBACK(cb_proctable_column_resized), procdata->settings);
         gtk_tree_view_column_set_reorderable(col, TRUE);
         gtk_tree_view_append_column(GTK_TREE_VIEW(proctree), col);
@@ -450,7 +432,7 @@ proctable_new (ProcData * const procdata)
                 break;
         }
 
-        // xaling
+        // xalign
         switch(i)
         {
             case COL_VMSIZE:
@@ -470,11 +452,10 @@ proctable_new (ProcData * const procdata)
         // sizing
         switch (i) {
             case COL_ARGS:
-                gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
                 gtk_tree_view_column_set_min_width(col, 150);
                 break;
             default:
-                gtk_tree_view_column_set_min_width(column, 20);
+                gtk_tree_view_column_set_min_width(col, 20);
                 break;
         }
     }
@@ -483,8 +464,6 @@ proctable_new (ProcData * const procdata)
 
     procdata->tree = proctree;
 
-    set_proctree_reorderable(procdata);
-
     procman_get_tree_state (procdata->settings, proctree, "proctree");
 
     /* Override column settings by hiding this column if it's meaningless: */
@@ -820,7 +799,12 @@ update_info (ProcData *procdata, ProcInfo *info)
 
     info->set_user(procstate.uid);
 
-    info->pcpu = (proctime.rtime - info->cpu_time) * 100 / procdata->cpu_total_time;
+    // if the cpu time has increased reset the status to running
+    // regardless of kernel state (https://bugzilla.gnome.org/606579)
+    guint64 difference = proctime.rtime - info->cpu_time;
+    if (difference > 0)
+        info->status = GLIBTOP_PROCESS_RUNNING;
+    info->pcpu = difference * 100 / procdata->cpu_total_time;
     info->pcpu = MIN(info->pcpu, 100);
 
     if (not procdata->config.solaris_mode)
@@ -1005,7 +989,7 @@ refresh_list (ProcData *procdata, const pid_t* pid_list, const guint n)
 }
 
 
-void
+static void
 proctable_update_list (ProcData * const procdata)
 {
     pid_t* pid_list;
@@ -1058,7 +1042,7 @@ proctable_update_list (ProcData * const procdata)
 
 
 void
-proctable_update_all (ProcData * const procdata)
+proctable_update (ProcData * const procdata)
 {
     char* string;
 
