@@ -631,11 +631,7 @@ namespace {
 #define LOGO_H 351
 #define RADIUS 5
 
-#if GTK_CHECK_VERSION(3,0,0)
 static gboolean sysinfo_logo_draw (GtkWidget *widget, cairo_t *context, gpointer data_ptr)
-#else
-static gboolean sysinfo_logo_expose (GtkWidget *widget, GdkEventExpose *event, gpointer data_ptr)
-#endif
 {
     GtkAllocation allocation;
     GtkStyle *style;
@@ -664,11 +660,11 @@ static gboolean sysinfo_logo_expose (GtkWidget *widget, GdkEventExpose *event, g
                                       style->base[GTK_STATE_SELECTED].green / 65535.0,
                                       style->base[GTK_STATE_SELECTED].blue / 65535.0,
                                       1.0);
-  cairo_pattern_add_color_stop_rgba(cp, 1.0,
-                                    style->base[GTK_STATE_SELECTED].red / 65535.0,
-                                    style->base[GTK_STATE_SELECTED].green / 65535.0,
-                                    style->base[GTK_STATE_SELECTED].blue / 65535.0,
-                                    0.0);
+    cairo_pattern_add_color_stop_rgba(cp, 1.0,
+                                      style->base[GTK_STATE_SELECTED].red / 65535.0,
+                                      style->base[GTK_STATE_SELECTED].green / 65535.0,
+                                      style->base[GTK_STATE_SELECTED].blue / 65535.0,
+                                      0.0);
     cairo_set_source(cr, cp);
     cairo_fill(cr);
 
@@ -696,9 +692,9 @@ add_section(GtkBox *vbox , const char * title, int num_row, int num_col, GtkWidg
     gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0, 12, 0);
     gtk_container_add(GTK_CONTAINER(frame), alignment);
 
-    table = gtk_table_new(num_row, num_col, FALSE);
-    gtk_table_set_row_spacings(GTK_TABLE(table), 6);
-    gtk_table_set_col_spacings(GTK_TABLE(table), 6);
+    table = gtk_grid_new();
+    gtk_grid_set_row_spacing(GTK_GRID(table), 6);
+    gtk_grid_set_column_spacing(GTK_GRID(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 6);
     gtk_container_add(GTK_CONTAINER(alignment), table);
 
@@ -710,26 +706,33 @@ add_section(GtkBox *vbox , const char * title, int num_row, int num_col, GtkWidg
 
 
 static GtkWidget*
-add_row(GtkTable * table, const char * label, const char * value, int row)
+add_row(GtkGrid * table, const char * label, const char * value, int row)
 {
     GtkWidget *header = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(header), label);
     gtk_label_set_selectable(GTK_LABEL(header), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(header), 0.0, 0.5);
-    gtk_table_attach(
+    gtk_widget_set_can_focus(header, FALSE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
+    gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
+    gtk_grid_attach(
         table, header,
-        0, 1, row, row + 1,
-        GTK_FILL, GTK_FILL, 0, 0
-        );
+        0, row, 1, 1);
 
     GtkWidget *label_widget = gtk_label_new(value);
     gtk_label_set_selectable(GTK_LABEL(label_widget), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(label_widget), 0.0, 0.5);
-    gtk_table_attach(
+    gtk_widget_set_can_focus(label_widget, FALSE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (label_widget), 0.0);
+#else
+    gtk_misc_set_alignment (GTK_MISC (label_widget), 0.0, 0.5);
+#endif
+    gtk_grid_attach(
         table, label_widget,
-        1, 2, row, row + 1,
-        GTK_FILL, GTK_FILL, 0, 0
-        );
+        1, row, 1, 1);
+
     return label_widget;
 }
 
@@ -755,7 +758,7 @@ procman_create_sysinfo_view(void)
 
     gchar *markup;
 
-    hbox = gtk_hbox_new(FALSE, 12);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 6);
 
     /* left-side logo */
@@ -765,17 +768,16 @@ procman_create_sysinfo_view(void)
     else {
         logo = gtk_image_new_from_file(DATADIR "/pixmaps/mate-system-monitor/side.png");
     }
-    gtk_misc_set_alignment(GTK_MISC(logo), 0.5, 0.0);
-    gtk_misc_set_padding(GTK_MISC(logo), 5, 12);
+    gtk_widget_set_valign (logo, GTK_ALIGN_START);
+    gtk_widget_set_margin_start (logo, 5);
+    gtk_widget_set_margin_end (logo, 5);
+    gtk_widget_set_margin_top (logo, 12);
+    gtk_widget_set_margin_bottom (logo, 12);
     gtk_box_pack_start(GTK_BOX(hbox), logo, FALSE, FALSE, 0);
 
-#if GTK_CHECK_VERSION(3,0,0)
     g_signal_connect(G_OBJECT(logo), "draw", G_CALLBACK(sysinfo_logo_draw), NULL);
-#else
-    g_signal_connect(G_OBJECT(logo), "expose-event", G_CALLBACK(sysinfo_logo_expose), NULL);
-#endif
 
-    vbox = gtk_vbox_new(FALSE, 12);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 12);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 
@@ -805,25 +807,31 @@ procman_create_sysinfo_view(void)
 
     distro_release_label = gtk_label_new("???");
     gtk_label_set_selectable(GTK_LABEL(distro_release_label), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(distro_release_label), 0.0, 0.5);
-    gtk_table_attach(
-        GTK_TABLE(distro_table), distro_release_label,
-        0, 1, table_count, table_count+1,
-        GTK_FILL, GTK_FILL, 0, 0
-        );
+    gtk_widget_set_can_focus(distro_release_label, FALSE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (distro_release_label), 0.0);
+#else
+    gtk_misc_set_alignment (GTK_MISC (distro_release_label), 0.0, 0.5);
+#endif
+    gtk_grid_attach(
+        GTK_GRID(distro_table), distro_release_label,
+        0, table_count, 1, 1);
     table_count++;
     data->set_distro_labels(gtk_frame_get_label_widget(GTK_FRAME(distro_frame)), distro_release_label);
 
     markup = g_strdup_printf(_("Kernel %s"), data->kernel.c_str());
     header = gtk_label_new(markup);
     gtk_label_set_selectable(GTK_LABEL(header), TRUE);
+    gtk_widget_set_can_focus(header, FALSE);
     g_free(markup);
-    gtk_misc_set_alignment(GTK_MISC(header), 0.0, 0.5);
-    gtk_table_attach(
-        GTK_TABLE(distro_table), header,
-        0, 1, table_count, table_count + 1,
-        GTK_FILL, GTK_FILL, 0, 0
-        );
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
+    gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
+    gtk_grid_attach(
+        GTK_GRID(distro_table), header,
+        0, table_count, 1, 1);
     table_count++;
 
     if (data->mate_version != "")
@@ -831,13 +839,16 @@ procman_create_sysinfo_view(void)
         markup = g_strdup_printf(_("MATE %s"), data->mate_version.c_str());
         header = gtk_label_new(markup);
         gtk_label_set_selectable(GTK_LABEL(header), TRUE);
+        gtk_widget_set_can_focus(header, FALSE);
         g_free(markup);
-        gtk_misc_set_alignment(GTK_MISC(header), 0.0, 0.5);
-        gtk_table_attach(
-            GTK_TABLE(distro_table), header,
-            0, 1, table_count, table_count + 1,
-            GTK_FILL, GTK_FILL, 0, 0
-            );
+#if GTK_CHECK_VERSION (3, 16, 0)
+        gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
+        gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
+        gtk_grid_attach(
+            GTK_GRID(distro_table), header,
+            0, table_count, 1, 1);
         table_count++;
     }
 
@@ -848,11 +859,11 @@ procman_create_sysinfo_view(void)
     g_free(markup);
 
     markup = procman::format_size(data->memory_bytes);
-    add_row(GTK_TABLE(hardware_table), _("Memory:"), markup, 0);
+    add_row(GTK_GRID(hardware_table), _("Memory:"), markup, 0);
     g_free(markup);
 
     markup = NULL;
-    add_row(GTK_TABLE(hardware_table), _("Processor:"),
+    add_row(GTK_GRID(hardware_table), _("Processor:"),
             data->processors.c_str(), 1);
 
     if(markup)
@@ -865,7 +876,7 @@ procman_create_sysinfo_view(void)
     g_free(markup);
 
     markup = procman::format_size(data->free_space_bytes);
-    add_row(GTK_TABLE(disk_space_table), _("Available disk space:"), markup, 0);
+    add_row(GTK_GRID(disk_space_table), _("Available disk space:"), markup, 0);
     g_free(markup);
 
     return hbox;
